#[non_exhaustive]pub enum NoteKind {
Show 15 variants
Unspecified,
Vulnerability,
Build,
Image,
Package,
Deployment,
Discovery,
Attestation,
Upgrade,
Compliance,
DsseAttestation,
VulnerabilityAssessment,
SbomReference,
Secret,
UnknownValue(UnknownValue),
}Expand description
Kind represents the kinds of notes supported.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. This value is unused.
Vulnerability
The note and occurrence represent a package vulnerability.
Build
The note and occurrence assert build provenance.
Image
This represents an image basis relationship.
Package
This represents a package installed via a package manager.
Deployment
The note and occurrence track deployment events.
Discovery
The note and occurrence track the initial discovery status of a resource.
Attestation
This represents a logical “role” that can attest to artifacts.
Upgrade
This represents an available package upgrade.
Compliance
This represents a Compliance Note
DsseAttestation
This represents a DSSE attestation Note
VulnerabilityAssessment
This represents a Vulnerability Assessment.
SbomReference
This represents an SBOM Reference.
Secret
This represents a secret.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NoteKind::value or NoteKind::name.
Implementations