#[non_exhaustive]pub enum Context {
CloudRepo(Box<CloudRepoSourceContext>),
Gerrit(Box<GerritSourceContext>),
Git(Box<GitSourceContext>),
}Expand description
A SourceContext can refer any one of the following types of repositories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CloudRepo(Box<CloudRepoSourceContext>)
A SourceContext referring to a revision in a Google Cloud Source Repo.
Gerrit(Box<GerritSourceContext>)
A SourceContext referring to a Gerrit project.
Git(Box<GitSourceContext>)
A SourceContext referring to any third party Git repo (e.g., GitHub).