#[non_exhaustive]pub struct AttestationNote {
pub hint: Option<Hint>,
/* private fields */
}Expand description
Note kind that represents a logical attestation “role” or “authority”. For
example, an organization might have one Authority for “QA” and one for
“build”. This note is intended to act strictly as a grouping mechanism for
the attached occurrences (Attestations). This grouping mechanism also
provides a security boundary, since IAM ACLs gate the ability for a principle
to attach an occurrence to a given note. It also provides a single point of
lookup to find all attached attestation occurrences, even if they don’t all
live in the same project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hint: Option<Hint>Hint hints at the purpose of the attestation authority.
Implementations
Sourceimpl AttestationNote
impl AttestationNote