#[non_exhaustive]pub struct BaseImage {
pub name: String,
pub repository: String,
pub layer_count: i32,
/* private fields */
}Expand description
BaseImage describes a base image of a container image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the base image.
repository: StringThe repository name in which the base image is from.
layer_count: i32The number of layers that the base image is composed of.
Implementations