#[non_exhaustive]pub struct BatchCreateOccurrencesRequest {
pub parent: String,
pub occurrences: Vec<Occurrence>,
/* private fields */
}Expand description
Request to create occurrences in batch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe name of the project in the form of projects/[PROJECT_ID], under which
the occurrences are to be created.
occurrences: Vec<Occurrence>The occurrences to create. Max allowed length is 1000.
Implementations
Sourceimpl BatchCreateOccurrencesRequest
impl BatchCreateOccurrencesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_occurrences<T, V>(self, v: T) -> Self
pub fn set_occurrences<T, V>(self, v: T) -> Self
Sets the value of occurrences.
Example
ⓘ
use google_cloud_grafeas_v1::model::Occurrence;
let x = BatchCreateOccurrencesRequest::new()
.set_occurrences([
Occurrence::default()/* use setters */,
Occurrence::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for BatchCreateOccurrencesRequest
impl Clone for BatchCreateOccurrencesRequest
Sourcefn clone(&self) -> BatchCreateOccurrencesRequest
fn clone(&self) -> BatchCreateOccurrencesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BatchCreateOccurrencesRequest
impl Default for BatchCreateOccurrencesRequest
Sourcefn default() -> BatchCreateOccurrencesRequest
fn default() -> BatchCreateOccurrencesRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for BatchCreateOccurrencesRequest
impl PartialEq for BatchCreateOccurrencesRequest
Sourcefn eq(&self, other: &BatchCreateOccurrencesRequest) -> bool
fn eq(&self, other: &BatchCreateOccurrencesRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchCreateOccurrencesRequest