#[non_exhaustive]pub struct Command {
pub name: String,
pub env: Vec<String>,
pub args: Vec<String>,
pub dir: String,
pub id: String,
pub wait_for: Vec<String>,
/* private fields */
}Expand description
Command describes a step performed as part of the build pipeline.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the command, as presented on the command line, or if the
command is packaged as a Docker container, as presented to docker pull.
env: Vec<String>Environment variables set before running this command.
args: Vec<String>Command-line arguments used when executing this command.
dir: StringWorking directory (relative to project source root) used when running this command.
id: StringOptional unique identifier for this command, used in wait_for to reference this command as a dependency.
wait_for: Vec<String>The ID(s) of the command(s) that this command depends on.
Implementations
Sourceimpl Command
impl Command
pub fn new() -> Self
Sourcepub fn set_wait_for<T, V>(self, v: T) -> Self
pub fn set_wait_for<T, V>(self, v: T) -> Self