#[non_exhaustive]pub struct DiscoveryNote {
pub analysis_kind: NoteKind,
/* private fields */
}Expand description
A note that indicates a type of analysis a provider would perform. This note
exists in a provider’s project. A Discovery occurrence is created in a
consumer’s project at the start of analysis.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.analysis_kind: NoteKindRequired. Immutable. The kind of analysis that is handled by this discovery.
Implementations
Sourceimpl DiscoveryNote
impl DiscoveryNote
pub fn new() -> Self
Sourcepub fn set_analysis_kind<T: Into<NoteKind>>(self, v: T) -> Self
pub fn set_analysis_kind<T: Into<NoteKind>>(self, v: T) -> Self
Sets the value of analysis_kind.
Example
ⓘ
use google_cloud_grafeas_v1::model::NoteKind;
let x0 = DiscoveryNote::new().set_analysis_kind(NoteKind::Vulnerability);
let x1 = DiscoveryNote::new().set_analysis_kind(NoteKind::Build);
let x2 = DiscoveryNote::new().set_analysis_kind(NoteKind::Image);Trait Implementations
Sourceimpl Clone for DiscoveryNote
impl Clone for DiscoveryNote
Sourcefn clone(&self) -> DiscoveryNote
fn clone(&self) -> DiscoveryNote
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscoveryNote
impl Debug for DiscoveryNote
Sourceimpl Default for DiscoveryNote
impl Default for DiscoveryNote
Sourcefn default() -> DiscoveryNote
fn default() -> DiscoveryNote
Returns the “default value” for a type. Read more
Sourceimpl Message for DiscoveryNote
impl Message for DiscoveryNote
Sourceimpl PartialEq for DiscoveryNote
impl PartialEq for DiscoveryNote
impl StructuralPartialEq for DiscoveryNote