#[non_exhaustive]pub struct ImageNote {
pub resource_url: String,
pub fingerprint: Option<Fingerprint>,
/* private fields */
}Expand description
Basis describes the base image portion (Note) of the DockerImage relationship. Linked occurrences are derived from this or an equivalent image via: FROM <Basis.resource_url> Or an equivalent reference, e.g., a tag of the resource_url.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_url: StringRequired. Immutable. The resource_url for the resource representing the basis of associated occurrence images.
fingerprint: Option<Fingerprint>Required. Immutable. The fingerprint of the base image.
Implementations
Sourceimpl ImageNote
impl ImageNote
pub fn new() -> Self
Sourcepub fn set_resource_url<T: Into<String>>(self, v: T) -> Self
pub fn set_resource_url<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_fingerprint<T>(self, v: T) -> Selfwhere
T: Into<Fingerprint>,
pub fn set_fingerprint<T>(self, v: T) -> Selfwhere
T: Into<Fingerprint>,
Sets the value of fingerprint.
Example
ⓘ
use google_cloud_grafeas_v1::model::Fingerprint;
let x = ImageNote::new().set_fingerprint(Fingerprint::default()/* use setters */);Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fingerprint>,
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fingerprint>,
Sets or clears the value of fingerprint.
Example
ⓘ
use google_cloud_grafeas_v1::model::Fingerprint;
let x = ImageNote::new().set_or_clear_fingerprint(Some(Fingerprint::default()/* use setters */));
let x = ImageNote::new().set_or_clear_fingerprint(None::<Fingerprint>);Trait Implementations
impl StructuralPartialEq for ImageNote