#[non_exhaustive]pub struct ImageOccurrence {
pub fingerprint: Option<Fingerprint>,
pub distance: i32,
pub layer_info: Vec<Layer>,
pub base_resource_url: String,
/* private fields */
}Expand description
Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM <DockerImage.Basis in attached Note>.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fingerprint: Option<Fingerprint>Required. The fingerprint of the derived image.
distance: i32Output only. The number of layers by which this image differs from the associated image basis.
layer_info: Vec<Layer>This contains layer-specific metadata, if populated it has length “distance” and is ordered with [distance] being the layer immediately following the base image and [1] being the final layer.
base_resource_url: StringOutput only. This contains the base image URL for the derived image occurrence.
Implementations
Sourceimpl ImageOccurrence
impl ImageOccurrence
pub fn new() -> Self
Sourcepub fn set_fingerprint<T>(self, v: T) -> Selfwhere
T: Into<Fingerprint>,
pub fn set_fingerprint<T>(self, v: T) -> Selfwhere
T: Into<Fingerprint>,
Sets the value of fingerprint.
Example
ⓘ
use google_cloud_grafeas_v1::model::Fingerprint;
let x = ImageOccurrence::new().set_fingerprint(Fingerprint::default()/* use setters */);Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fingerprint>,
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Selfwhere
T: Into<Fingerprint>,
Sets or clears the value of fingerprint.
Example
ⓘ
use google_cloud_grafeas_v1::model::Fingerprint;
let x = ImageOccurrence::new().set_or_clear_fingerprint(Some(Fingerprint::default()/* use setters */));
let x = ImageOccurrence::new().set_or_clear_fingerprint(None::<Fingerprint>);Sourcepub fn set_distance<T: Into<i32>>(self, v: T) -> Self
pub fn set_distance<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_layer_info<T, V>(self, v: T) -> Self
pub fn set_layer_info<T, V>(self, v: T) -> Self
Sets the value of layer_info.
Example
ⓘ
use google_cloud_grafeas_v1::model::Layer;
let x = ImageOccurrence::new()
.set_layer_info([
Layer::default()/* use setters */,
Layer::default()/* use (different) setters */,
]);Sourcepub fn set_base_resource_url<T: Into<String>>(self, v: T) -> Self
pub fn set_base_resource_url<T: Into<String>>(self, v: T) -> Self
Sets the value of base_resource_url.
Example
ⓘ
let x = ImageOccurrence::new().set_base_resource_url("example");Trait Implementations
Sourceimpl Clone for ImageOccurrence
impl Clone for ImageOccurrence
Sourcefn clone(&self) -> ImageOccurrence
fn clone(&self) -> ImageOccurrence
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageOccurrence
impl Debug for ImageOccurrence
Sourceimpl Default for ImageOccurrence
impl Default for ImageOccurrence
Sourcefn default() -> ImageOccurrence
fn default() -> ImageOccurrence
Returns the “default value” for a type. Read more
Sourceimpl Message for ImageOccurrence
impl Message for ImageOccurrence
Sourceimpl PartialEq for ImageOccurrence
impl PartialEq for ImageOccurrence
impl StructuralPartialEq for ImageOccurrence