#[non_exhaustive]pub struct ListNoteOccurrencesRequest {
pub name: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request to list occurrences for a note.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the note to list occurrences for in the form of
projects/[PROVIDER_ID]/notes/[NOTE_ID].
filter: StringThe filter expression.
page_size: i32Number of occurrences to return in the list.
page_token: StringToken to provide to skip to a particular spot in the list.
Implementations
Sourceimpl ListNoteOccurrencesRequest
impl ListNoteOccurrencesRequest
pub fn new() -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListNoteOccurrencesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListNoteOccurrencesRequest
impl Clone for ListNoteOccurrencesRequest
Sourcefn clone(&self) -> ListNoteOccurrencesRequest
fn clone(&self) -> ListNoteOccurrencesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListNoteOccurrencesRequest
impl Debug for ListNoteOccurrencesRequest
Sourceimpl Default for ListNoteOccurrencesRequest
impl Default for ListNoteOccurrencesRequest
Sourcefn default() -> ListNoteOccurrencesRequest
fn default() -> ListNoteOccurrencesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListNoteOccurrencesRequest
impl Message for ListNoteOccurrencesRequest
impl StructuralPartialEq for ListNoteOccurrencesRequest