ListNotesRequest

Struct ListNotesRequest 

#[non_exhaustive]
pub struct ListNotesRequest { pub parent: String, pub filter: String, pub page_size: i32, pub page_token: String, pub return_partial_success: bool, /* private fields */ }
Request to list notes.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

The name of the project to list notes for in the form of projects/[PROJECT_ID].

filter: String

The filter expression.

page_size: i32

Number of notes to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.

page_token: String

Token to provide to skip to a particular spot in the list.

return_partial_success: bool

If set, the request will return all reachable Notes and report all unreachable regions in the unreachable field in the response.

Only applicable for requests in the global region.

Implementations

Source

impl ListNotesRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListNotesRequest::new().set_parent("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListNotesRequest::new().set_filter("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListNotesRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListNotesRequest::new().set_page_token("example");
pub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self

Sets the value of return_partial_success.

Example
let x = ListNotesRequest::new().set_return_partial_success(true);