PackageNote

Struct PackageNote 

#[non_exhaustive]
pub struct PackageNote { pub name: String, pub distribution: Vec<Distribution>, pub package_type: String, pub cpe_uri: String, pub architecture: Architecture, pub version: Option<Version>, pub maintainer: String, pub url: String, pub description: String, pub license: Option<License>, pub digest: Vec<Digest>, /* private fields */ }
PackageNote represents a particular package version.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The name of the package.

distribution: Vec<Distribution>

Deprecated. The various channels by which a package is distributed.

package_type: String

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).

cpe_uri: String

The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages.

architecture: Architecture

The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages.

version: Option<Version>

The version of the package.

maintainer: String

A freeform text denoting the maintainer of this package.

url: String

The homepage for this package.

description: String

The description of this package.

license: Option<License>

Licenses that have been declared by the authors of the package.

digest: Vec<Digest>

Hash value, typically a file digest, that allows unique identification a specific package.

Implementations

Source

impl PackageNote

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = PackageNote::new().set_name("example");
pub fn set_distribution<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Distribution>,

Sets the value of distribution.

Example
use google_cloud_grafeas_v1::model::Distribution;
let x = PackageNote::new()
    .set_distribution([
        Distribution::default()/* use setters */,
        Distribution::default()/* use (different) setters */,
    ]);
pub fn set_package_type<T: Into<String>>(self, v: T) -> Self

Sets the value of package_type.

Example
let x = PackageNote::new().set_package_type("example");
pub fn set_cpe_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of cpe_uri.

Example
let x = PackageNote::new().set_cpe_uri("example");
pub fn set_architecture<T: Into<Architecture>>(self, v: T) -> Self

Sets the value of architecture.

Example
use google_cloud_grafeas_v1::model::Architecture;
let x0 = PackageNote::new().set_architecture(Architecture::X86);
let x1 = PackageNote::new().set_architecture(Architecture::X64);
pub fn set_version<T>(self, v: T) -> Self
where T: Into<Version>,

Sets the value of version.

Example
use google_cloud_grafeas_v1::model::Version;
let x = PackageNote::new().set_version(Version::default()/* use setters */);
pub fn set_or_clear_version<T>(self, v: Option<T>) -> Self
where T: Into<Version>,

Sets or clears the value of version.

Example
use google_cloud_grafeas_v1::model::Version;
let x = PackageNote::new().set_or_clear_version(Some(Version::default()/* use setters */));
let x = PackageNote::new().set_or_clear_version(None::<Version>);
pub fn set_maintainer<T: Into<String>>(self, v: T) -> Self

Sets the value of maintainer.

Example
let x = PackageNote::new().set_maintainer("example");
pub fn set_url<T: Into<String>>(self, v: T) -> Self

Sets the value of url.

Example
let x = PackageNote::new().set_url("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = PackageNote::new().set_description("example");
pub fn set_license<T>(self, v: T) -> Self
where T: Into<License>,

Sets the value of license.

Example
use google_cloud_grafeas_v1::model::License;
let x = PackageNote::new().set_license(License::default()/* use setters */);
pub fn set_or_clear_license<T>(self, v: Option<T>) -> Self
where T: Into<License>,

Sets or clears the value of license.

Example
use google_cloud_grafeas_v1::model::License;
let x = PackageNote::new().set_or_clear_license(Some(License::default()/* use setters */));
let x = PackageNote::new().set_or_clear_license(None::<License>);
pub fn set_digest<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Digest>,

Sets the value of digest.

Example
use google_cloud_grafeas_v1::model::Digest;
let x = PackageNote::new()
    .set_digest([
        Digest::default()/* use setters */,
        Digest::default()/* use (different) setters */,
    ]);