#[non_exhaustive]pub struct SbomReferenceIntotoPredicate {
pub referrer_id: String,
pub location: String,
pub mime_type: String,
pub digest: HashMap<String, String>,
/* private fields */
}Expand description
A predicate which describes the SBOM being referenced.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.referrer_id: StringThe person or system referring this predicate to the consumer.
location: StringThe location of the SBOM.
mime_type: StringThe mime type of the SBOM.
digest: HashMap<String, String>A map of algorithm to digest of the contents of the SBOM.
Implementations
Sourceimpl SbomReferenceIntotoPredicate
impl SbomReferenceIntotoPredicate
pub fn new() -> Self
Sourcepub fn set_referrer_id<T: Into<String>>(self, v: T) -> Self
pub fn set_referrer_id<T: Into<String>>(self, v: T) -> Self
Sets the value of referrer_id.
Example
ⓘ
let x = SbomReferenceIntotoPredicate::new().set_referrer_id("example");Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mime_type<T: Into<String>>(self, v: T) -> Self
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self