UpgradeDistribution

Struct UpgradeDistribution 

#[non_exhaustive]
pub struct UpgradeDistribution { pub cpe_uri: String, pub classification: String, pub severity: String, pub cve: Vec<String>, /* private fields */ }
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cpe_uri: String

Required - The specific operating system this metadata applies to. See https://cpe.mitre.org/specification/.

classification: String

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous-versions/windows/desktop/ff357803(v=vs.85)

severity: String

The severity as specified by the upstream operating system.

cve: Vec<String>

The cve tied to this Upgrade.

Implementations

Source

impl UpgradeDistribution

pub fn new() -> Self

pub fn set_cpe_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of cpe_uri.

Example
let x = UpgradeDistribution::new().set_cpe_uri("example");
pub fn set_classification<T: Into<String>>(self, v: T) -> Self

Sets the value of classification.

Example
let x = UpgradeDistribution::new().set_classification("example");
pub fn set_severity<T: Into<String>>(self, v: T) -> Self

Sets the value of severity.

Example
let x = UpgradeDistribution::new().set_severity("example");
pub fn set_cve<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of cve.

Example
let x = UpgradeDistribution::new().set_cve(["a", "b", "c"]);