Version

Struct Version 

#[non_exhaustive]
pub struct Version { pub epoch: i32, pub name: String, pub revision: String, pub inclusive: bool, pub kind: VersionKind, pub full_name: String, /* private fields */ }
Version contains structured information about the version of a package.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
epoch: i32

Used to correct mistakes in the version numbering scheme.

name: String

Required only when version kind is NORMAL. The main part of the version name.

revision: String

The iteration of the package build from the above version.

inclusive: bool

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range.

kind: VersionKind

Required. Distinguishes between sentinel MIN/MAX versions and normal versions.

full_name: String

Human readable version string. This string is of the form <epoch>:<name>-<revision> and is only set when kind is NORMAL.

Implementations

Source

impl Version

pub fn new() -> Self

pub fn set_epoch<T: Into<i32>>(self, v: T) -> Self

Sets the value of epoch.

Example
let x = Version::new().set_epoch(42);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Version::new().set_name("example");
pub fn set_revision<T: Into<String>>(self, v: T) -> Self

Sets the value of revision.

Example
let x = Version::new().set_revision("example");
pub fn set_inclusive<T: Into<bool>>(self, v: T) -> Self

Sets the value of inclusive.

Example
let x = Version::new().set_inclusive(true);
pub fn set_kind<T: Into<VersionKind>>(self, v: T) -> Self

Sets the value of kind.

Example
use google_cloud_grafeas_v1::model::version::VersionKind;
let x0 = Version::new().set_kind(VersionKind::Normal);
let x1 = Version::new().set_kind(VersionKind::Minimum);
let x2 = Version::new().set_kind(VersionKind::Maximum);
pub fn set_full_name<T: Into<String>>(self, v: T) -> Self

Sets the value of full_name.

Example
let x = Version::new().set_full_name("example");