#[non_exhaustive]pub struct WindowsUpdate {
pub identity: Option<Identity>,
pub title: String,
pub description: String,
pub categories: Vec<Category>,
pub kb_article_ids: Vec<String>,
pub support_url: String,
pub last_published_timestamp: Option<Timestamp>,
/* private fields */
}Expand description
Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn-wuapi-iupdate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity: Option<Identity>Required - The unique identifier for the update.
title: StringThe localized title of the update.
description: StringThe localized description of the update.
categories: Vec<Category>The list of categories to which the update belongs.
kb_article_ids: Vec<String>The Microsoft Knowledge Base article IDs that are associated with the update.
support_url: StringThe hyperlink to the support information for the update.
last_published_timestamp: Option<Timestamp>The last published timestamp of the update.
Implementations
Sourceimpl WindowsUpdate
impl WindowsUpdate
pub fn new() -> Self
Sourcepub fn set_identity<T>(self, v: T) -> Self
pub fn set_identity<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_identity<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_identity<T>(self, v: Option<T>) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_categories<T, V>(self, v: T) -> Self
pub fn set_categories<T, V>(self, v: T) -> Self
Sets the value of categories.
Example
ⓘ
use google_cloud_grafeas_v1::model::windows_update::Category;
let x = WindowsUpdate::new()
.set_categories([
Category::default()/* use setters */,
Category::default()/* use (different) setters */,
]);Sourcepub fn set_kb_article_ids<T, V>(self, v: T) -> Self
pub fn set_kb_article_ids<T, V>(self, v: T) -> Self
Sets the value of kb_article_ids.
Example
ⓘ
let x = WindowsUpdate::new().set_kb_article_ids(["a", "b", "c"]);Sourcepub fn set_support_url<T: Into<String>>(self, v: T) -> Self
pub fn set_support_url<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_last_published_timestamp<T>(self, v: T) -> Self
pub fn set_last_published_timestamp<T>(self, v: T) -> Self
Sets the value of last_published_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = WindowsUpdate::new().set_last_published_timestamp(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_published_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_published_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_published_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = WindowsUpdate::new().set_or_clear_last_published_timestamp(Some(Timestamp::default()/* use setters */));
let x = WindowsUpdate::new().set_or_clear_last_published_timestamp(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for WindowsUpdate
impl Clone for WindowsUpdate
Sourcefn clone(&self) -> WindowsUpdate
fn clone(&self) -> WindowsUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WindowsUpdate
impl Debug for WindowsUpdate
Sourceimpl Default for WindowsUpdate
impl Default for WindowsUpdate
Sourcefn default() -> WindowsUpdate
fn default() -> WindowsUpdate
Returns the “default value” for a type. Read more
Sourceimpl Message for WindowsUpdate
impl Message for WindowsUpdate
Sourceimpl PartialEq for WindowsUpdate
impl PartialEq for WindowsUpdate
impl StructuralPartialEq for WindowsUpdate