#[non_exhaustive]pub struct ListNotesRequest {
pub parent: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
pub return_partial_success: bool,
/* private fields */
}Expand description
Request to list notes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe name of the project to list notes for in the form of
projects/[PROJECT_ID].
filter: StringThe filter expression.
page_size: i32Number of notes to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.
page_token: StringToken to provide to skip to a particular spot in the list.
return_partial_success: boolIf set, the request will return all reachable Notes
and report all unreachable regions in the unreachable field in
the response.
Only applicable for requests in the global region.
Implementations
Sourceimpl ListNotesRequest
impl ListNotesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
pub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
Sets the value of return_partial_success.
Example
ⓘ
let x = ListNotesRequest::new().set_return_partial_success(true);Trait Implementations
Sourceimpl Clone for ListNotesRequest
impl Clone for ListNotesRequest
Sourcefn clone(&self) -> ListNotesRequest
fn clone(&self) -> ListNotesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListNotesRequest
impl Debug for ListNotesRequest
Sourceimpl Default for ListNotesRequest
impl Default for ListNotesRequest
Sourcefn default() -> ListNotesRequest
fn default() -> ListNotesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListNotesRequest
impl Message for ListNotesRequest
Sourceimpl PartialEq for ListNotesRequest
impl PartialEq for ListNotesRequest
impl StructuralPartialEq for ListNotesRequest