Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
Whether this version is specifying part of an inclusive range. Grafeas
does not have the capability to specify version ranges; instead we have
fields that specify start version and end versions. At times this is
insufficient - we also need to specify whether the version is included in
the range or is excluded from the range. This boolean is expected to be set
to true when the version is included in a range.
use google_cloud_grafeas_v1::model::version::VersionKind;
let x0 = Version::new().set_kind(VersionKind::Normal);
let x1 = Version::new().set_kind(VersionKind::Minimum);
let x2 = Version::new().set_kind(VersionKind::Maximum);